#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Strategy;

#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// Example of using GomOrderFlowLevels in a strategy
    /// </summary>
    [Description("Example of using GomOrderFlowLevels in a strategy")]
    public class GomMPPrevPOCSampleStrat : Strategy
    {
        #region Variables
        
		// Wizard generated variables
        private int target = 10; // Default setting for Target
        private int stop = 10; // Default setting for Stop
        // User defined variables (add any user defined variables below)
		private GomMPProLevels gmpl;
        
		#endregion


		
        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
            SetProfitTarget("L", CalculationMode.Ticks, Target);
            SetStopLoss("L", CalculationMode.Ticks, Stop, false);

            CalculateOnBarClose = true;
			
			// you can use the ninja strategy builder to get the correct initializer
			// here are the enums:
			
			// public enum DeltaCalcType {BidAsk,UpDownTick};
			// public enum ImbalanceComparisonType { Ratio, Difference };
			// public enum ImbalanceTypeType { Diagonal, Horizontal, Both };
			// public enum SRZoneEndConditionType { FullCandleCross, SimpleCross, PocCross };

			gmpl=	GomMPProLevels(Gom.MP.DataSourceType.MinuteData, false, 0,1, Gom.MP.Periodicity.Daily, 
					"17:00:00", "09:00:00", Gom.Lib.GomTZ.TIMEZONE_LOCAL, 1,false, 70, 5,
					Gom.MP.ProfileData.Volume);

        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (FirstTickOfBar)
			{
				gmpl.Update();
							
				if (Close[0]> gmpl.PreviousPOC[0])
					EnterLongLimit(Convert.ToInt32(DefaultQuantity), gmpl.PreviousPOC[0], "L");	
			}
        }

        #region Properties
        [Description("")]
        [GridCategory("Parameters")]
        public int Target
        {
            get { return target; }
            set { target = Math.Max(1, value); }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public int Stop
        {
            get { return stop; }
            set { stop = Math.Max(1, value); }
        }

        #endregion
    }
}
